@@ -65,7 +65,6 @@ change_folder (CamelStore *store,
 {
 	CamelFolderInfo *fi;
 	const gchar *tmp;
-	CamelURL *url;
 
 	fi = camel_folder_info_new ();
 	fi->full_name = g_strdup (name);
@@ -74,19 +73,13 @@ change_folder (CamelStore *store,
 		tmp = name;
 	else
 		tmp++;
-	fi->name = g_strdup (tmp);
-	url = camel_url_new ("vfolder:", NULL);
-	camel_url_set_path (url, ((CamelService *)store)->url->path);
-	if (flags & CHANGE_NOSELECT)
-		camel_url_set_param (url, "noselect", "yes");
-	camel_url_set_fragment (url, name);
-	fi->uri = camel_url_to_string (url, 0);
-	camel_url_free (url);
-	/*fi->url = g_strdup_printf ("vfolder:%s%s#%s", ((CamelService *)store)->url->path, (flags&CHANGE_NOSELECT)?";noselect=yes":"", name);*/
+	fi->display_name = g_strdup (tmp);
 	fi->unread = count;
 	fi->flags = CAMEL_FOLDER_VIRTUAL;
 	if (!(flags & CHANGE_DELETE))
 		fi->flags |= CAMEL_FOLDER_NOCHILDREN;
+	if (flags & CHANGE_NOSELECT)
+		fi->flags |= CAMEL_FOLDER_NOSELECT;
 	if (flags & CHANGE_DELETE)
 		camel_store_folder_deleted (store, fi);
 	else
@@ -113,37 +106,30 @@ vee_store_finalize (GObject *object)
 	G_OBJECT_CLASS (camel_vee_store_parent_class)->finalize (object);
 }
 
-static gboolean
-vee_store_construct (CamelService *service,
-                     CamelSession *session,
-                     CamelProvider *provider,
-                     CamelURL *url,
-                     GError **error)
+static void
+vee_store_constructed (GObject *object)
 {
-	CamelServiceClass *service_class;
-	CamelStore *store;
 	CamelVeeStore *vee_store;
 
-	store = CAMEL_STORE (service);
-	vee_store = CAMEL_VEE_STORE (service);
+	vee_store = CAMEL_VEE_STORE (object);
 
-	/* Chain up to parent's construct() method. */
-	service_class = CAMEL_SERVICE_CLASS (camel_vee_store_parent_class);
-	if (!service_class->construct (service, session, provider, url, error))
-		return FALSE;
+	/* Chain up to parent's constructed() method. */
+	G_OBJECT_CLASS (camel_vee_store_parent_class)->constructed (object);
 
-	/* Set up unmatched folder */
 #ifndef VEE_UNMATCHED_ENABLE
+	/* Set up unmatched folder */
 	vee_store->unmatched_uids = g_hash_table_new (g_str_hash, g_str_equal);
 	vee_store->folder_unmatched = g_object_new (
 		CAMEL_TYPE_VEE_FOLDER,
 		"full-name", CAMEL_UNMATCHED_NAME,
-		"name", _("Unmatched"), "parent-store", store, NULL);
-	camel_vee_folder_construct (vee_store->folder_unmatched, CAMEL_STORE_FOLDER_PRIVATE);
-	camel_db_create_vfolder (store->cdb_r, _("Unmatched"), NULL);
+		"display-name", _("Unmatched"),
+		"parent-store", vee_store, NULL);
+	camel_vee_folder_construct (
+		vee_store->folder_unmatched, CAMEL_STORE_FOLDER_PRIVATE);
+	camel_db_create_vfolder (
+		CAMEL_STORE (vee_store)->cdb_r, _("Unmatched"), NULL);
 #endif
 
-	return TRUE;
 }
 
 static gchar *
@@ -206,7 +192,6 @@ vee_store_get_folder_info_sync (CamelStore *store,
 	CamelFolderInfo *info, *res = NULL, *tail;
 	GPtrArray *folders;
 	GHashTable *infos_hash;
-	CamelURL *url;
 	gint i;
 
 	d (printf ("Get folder info '%s'\n", top?top:"<null>"));
@@ -217,13 +202,13 @@ vee_store_get_folder_info_sync (CamelStore *store,
 	for (i=0;i<folders->len;i++) {
 		CamelVeeFolder *folder = folders->pdata[i];
 		const gchar *full_name;
-		const gchar *name;
+		const gchar *display_name;
 		gint add = FALSE;
 		gchar *pname, *tmp;
 		CamelFolderInfo *pinfo;
 
-		name = camel_folder_get_name (CAMEL_FOLDER (folder));
 		full_name = camel_folder_get_full_name (CAMEL_FOLDER (folder));
+		display_name = camel_folder_get_display_name (CAMEL_FOLDER (folder));
 
 		/* check we have to include this one */
 		if (top) {
@@ -242,10 +227,8 @@ vee_store_get_folder_info_sync (CamelStore *store,
 				|| strchr (full_name, '/') == NULL;
 		}
 
-		d (printf ("%sadding '%s'\n", add?"":"not ", name));
-
 		if (add) {
-			CamelStore *parent_store;
+			gint32 unread;
 
 			/* ensures unread is correct */
 			if ((flags & CAMEL_STORE_FOLDER_INFO_FAST) == 0)
@@ -253,18 +236,16 @@ vee_store_get_folder_info_sync (CamelStore *store,
 					(CamelFolder *)folder,
 					cancellable, NULL);
 
-			parent_store = camel_folder_get_parent_store (CAMEL_FOLDER (folder));
+			unread = camel_folder_get_unread_message_count (
+				CAMEL_FOLDER (folder));
 
 			info = camel_folder_info_new ();
-			url = camel_url_new ("vfolder:", NULL);
-			camel_url_set_path (url, ((CamelService *) parent_store)->url->path);
-			camel_url_set_fragment (url, full_name);
-			info->uri = camel_url_to_string (url, 0);
-			camel_url_free (url);
 			info->full_name = g_strdup (full_name);
-			info->name = g_strdup (name);
-			info->unread = camel_folder_get_unread_message_count ((CamelFolder *)folder);
-			info->flags = CAMEL_FOLDER_NOCHILDREN|CAMEL_FOLDER_VIRTUAL;
+			info->display_name = g_strdup (display_name);
+			info->unread = unread;
+			info->flags =
+				CAMEL_FOLDER_NOCHILDREN |
+				CAMEL_FOLDER_VIRTUAL;
 			g_hash_table_insert (infos_hash, info->full_name, info);
 
 			if (res == NULL)
@@ -312,16 +293,14 @@ vee_store_get_folder_info_sync (CamelStore *store,
 	/* FIXME[disk-summary] comment it out well */
 	if ((top == NULL || top[0] == 0 || strncmp (top, CAMEL_UNMATCHED_NAME, strlen (CAMEL_UNMATCHED_NAME)) == 0)) {
 		info = camel_folder_info_new ();
-		url = camel_url_new ("vfolder:", NULL);
-		camel_url_set_path (url, ((CamelService *)store)->url->path);
-		camel_url_set_fragment (url, CAMEL_UNMATCHED_NAME);
-		info->uri = camel_url_to_string (url, 0);
-		camel_url_free (url);
-		/*info->url = g_strdup_printf ("vfolder:%s#%s", ((CamelService *)store)->url->path, CAMEL_UNMATCHED_NAME);*/
 		info->full_name = g_strdup (CAMEL_UNMATCHED_NAME);
-		info->name = g_strdup (_("Unmatched"));
+		info->display_name = g_strdup (_("Unmatched"));
 		info->unread = -1;
-		info->flags = CAMEL_FOLDER_NOCHILDREN|CAMEL_FOLDER_NOINFERIORS|CAMEL_FOLDER_SYSTEM|CAMEL_FOLDER_VIRTUAL;
+		info->flags =
+			CAMEL_FOLDER_NOCHILDREN |
+			CAMEL_FOLDER_NOINFERIORS |
+			CAMEL_FOLDER_SYSTEM |
+			CAMEL_FOLDER_VIRTUAL;
 
 		if (res == NULL)
 			res = info;
@@ -462,9 +441,9 @@ camel_vee_store_class_init (CamelVeeStoreClass *class)
 
 	object_class = G_OBJECT_CLASS (class);
 	object_class->finalize = vee_store_finalize;
+	object_class->constructed = vee_store_constructed;
 
 	service_class = CAMEL_SERVICE_CLASS (class);
-	service_class->construct = vee_store_construct;
 	service_class->get_name = vee_store_get_name;
 
 	store_class = CAMEL_STORE_CLASS (class);
