@@ -52,6 +52,7 @@ static struct {
 };
 
 struct _transfer_data {
+	GCancellable *cancellable;
 	CamelFolder *folder;
 	CamelFolder *dest;
 	GPtrArray *uids;
@@ -67,22 +68,28 @@ transfer_messages (CamelFolder *folder,
 {
 	gint i;
 
-	camel_folder_transfer_messages_to (
-		md->folder, md->uids, md->dest, NULL, md->delete, error);
+	camel_folder_transfer_messages_to_sync (
+		md->folder, md->uids, md->dest,
+		md->delete, NULL, md->cancellable, error);
+
+	if (md->cancellable != NULL)
+		g_object_unref (md->cancellable);
 
 	for (i=0;i<md->uids->len;i++)
-		g_free(md->uids->pdata[i]);
-	g_ptr_array_free(md->uids, TRUE);
+		g_free (md->uids->pdata[i]);
+
+	g_ptr_array_free (md->uids, TRUE);
 	g_object_unref (md->folder);
-	g_free(md);
+	g_free (md);
 }
 
 static gboolean
-vtrash_folder_append_message (CamelFolder *folder,
-                              CamelMimeMessage *message,
-                              const CamelMessageInfo *info,
-                              gchar **appended_uid,
-                              GError **error)
+vtrash_folder_append_message_sync (CamelFolder *folder,
+                                   CamelMimeMessage *message,
+                                   CamelMessageInfo *info,
+                                   gchar **appended_uid,
+                                   GCancellable *cancellable,
+                                   GError **error)
 {
 	g_set_error (
 		error, CAMEL_ERROR, CAMEL_ERROR_GENERIC, "%s",
@@ -92,12 +99,13 @@ vtrash_folder_append_message (CamelFolder *folder,
 }
 
 static gboolean
-vtrash_folder_transfer_messages_to (CamelFolder *source,
-                                    GPtrArray *uids,
-                                    CamelFolder *dest,
-                                    GPtrArray **transferred_uids,
-                                    gboolean delete_originals,
-                                    GError **error)
+vtrash_folder_transfer_messages_to_sync (CamelFolder *source,
+                                         GPtrArray *uids,
+                                         CamelFolder *dest,
+                                         gboolean delete_originals,
+                                         GPtrArray **transferred_uids,
+                                         GCancellable *cancellable,
+                                         GError **error)
 {
 	CamelVeeMessageInfo *mi;
 	gint i;
@@ -125,7 +133,9 @@ vtrash_folder_transfer_messages_to (CamelFolder *source,
 
 		/* Move to trash is the same as setting the message flag */
 		for (i = 0; i < uids->len; i++)
-			camel_folder_set_message_flags(source, uids->pdata[i], ((CamelVTrashFolder *)dest)->bit, ~0);
+			camel_folder_set_message_flags (
+				source, uids->pdata[i],
+				((CamelVTrashFolder *)dest)->bit, ~0);
 		return TRUE;
 	}
 
@@ -144,30 +154,34 @@ vtrash_folder_transfer_messages_to (CamelFolder *source,
 
 		if (dest == mi->summary->folder) {
 			/* Just unset the flag on the original message */
-			camel_folder_set_message_flags (source, uids->pdata[i], sbit, 0);
+			camel_folder_set_message_flags (
+				source, uids->pdata[i], sbit, 0);
 		} else {
 			if (batch == NULL)
-				batch = g_hash_table_new(NULL, NULL);
-			md = g_hash_table_lookup(batch, mi->summary->folder);
+				batch = g_hash_table_new (NULL, NULL);
+			md = g_hash_table_lookup (batch, mi->summary->folder);
 			if (md == NULL) {
-				md = g_malloc0(sizeof(*md));
+				md = g_malloc0 (sizeof (*md));
+				md->cancellable = cancellable;
 				md->folder = g_object_ref (mi->summary->folder);
-				md->uids = g_ptr_array_new();
+				md->uids = g_ptr_array_new ();
 				md->dest = dest;
-				g_hash_table_insert(batch, mi->summary->folder, md);
+				if (cancellable != NULL)
+					g_object_ref (cancellable);
+				g_hash_table_insert (batch, mi->summary->folder, md);
 			}
 
 			tuid = uids->pdata[i];
-			if (strlen(tuid)>8)
+			if (strlen (tuid)>8)
 				tuid += 8;
-			g_ptr_array_add(md->uids, g_strdup(tuid));
+			g_ptr_array_add (md->uids, g_strdup (tuid));
 		}
 		camel_folder_free_message_info (source, (CamelMessageInfo *)mi);
 	}
 
 	if (batch) {
-		g_hash_table_foreach(batch, (GHFunc)transfer_messages, error);
-		g_hash_table_destroy(batch);
+		g_hash_table_foreach (batch, (GHFunc)transfer_messages, error);
+		g_hash_table_destroy (batch);
 	}
 
 	return TRUE;
@@ -179,8 +193,8 @@ camel_vtrash_folder_class_init (CamelVTrashFolderClass *class)
 	CamelFolderClass *folder_class;
 
 	folder_class = CAMEL_FOLDER_CLASS (class);
-	folder_class->append_message = vtrash_folder_append_message;
-	folder_class->transfer_messages_to = vtrash_folder_transfer_messages_to;
+	folder_class->append_message_sync = vtrash_folder_append_message_sync;
+	folder_class->transfer_messages_to_sync = vtrash_folder_transfer_messages_to_sync;
 }
 
 static void
@@ -203,12 +217,12 @@ camel_vtrash_folder_new (CamelStore *parent_store, camel_vtrash_folder_t type)
 {
 	CamelVTrashFolder *vtrash;
 
-	g_assert(type < CAMEL_VTRASH_FOLDER_LAST);
+	g_assert (type < CAMEL_VTRASH_FOLDER_LAST);
 
 	vtrash = g_object_new (
 		CAMEL_TYPE_VTRASH_FOLDER,
 		"full-name", vdata[type].full_name,
-		"name", gettext (vdata[type].name),
+		"display-name", gettext (vdata[type].name),
 		"parent-store", parent_store, NULL);
 
 	camel_vee_folder_construct (
@@ -219,7 +233,7 @@ camel_vtrash_folder_new (CamelStore *parent_store, camel_vtrash_folder_t type)
 		CAMEL_STORE_VEE_FOLDER_SPECIAL);
 
 	((CamelFolder *)vtrash)->folder_flags |= vdata[type].flags;
-	camel_vee_folder_set_expression((CamelVeeFolder *)vtrash, vdata[type].expr);
+	camel_vee_folder_set_expression ((CamelVeeFolder *)vtrash, vdata[type].expr);
 	vtrash->bit = vdata[type].bit;
 	vtrash->type = type;
 
