@@ -31,10 +31,6 @@
 #include "camel-imap-folder.h"
 #include "camel-imap-wrapper.h"
 
-#define CAMEL_IMAP_WRAPPER_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), CAMEL_TYPE_IMAP_WRAPPER, CamelImapWrapperPrivate))
-
 struct _CamelImapWrapperPrivate {
 	GMutex *lock;
 };
@@ -148,7 +144,9 @@ camel_imap_wrapper_class_init (CamelImapWrapperClass *class)
 static void
 camel_imap_wrapper_init (CamelImapWrapper *imap_wrapper)
 {
-	imap_wrapper->priv = CAMEL_IMAP_WRAPPER_GET_PRIVATE (imap_wrapper);
+	imap_wrapper->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		imap_wrapper, CAMEL_TYPE_IMAP_WRAPPER,
+		CamelImapWrapperPrivate);
 	imap_wrapper->priv->lock = g_mutex_new ();
 }
 
@@ -161,12 +159,15 @@ camel_imap_wrapper_new (CamelImapFolder *imap_folder,
 	CamelImapWrapper *imap_wrapper;
 	CamelStore *store;
 	CamelStream *stream;
+	CamelURL *url;
 	gboolean sync_offline = FALSE;
 
 	store = camel_folder_get_parent_store (CAMEL_FOLDER (imap_folder));
+	url = camel_service_get_camel_url (CAMEL_SERVICE (store));
 	sync_offline =
-		camel_url_get_param (((CamelService *) store)->url, "sync_offline") != NULL ||
-		camel_offline_folder_get_offline_sync (CAMEL_OFFLINE_FOLDER (imap_folder));
+		camel_url_get_param (url, "sync_offline") != NULL ||
+		camel_offline_folder_get_offline_sync (
+			CAMEL_OFFLINE_FOLDER (imap_folder));
 
 	imap_wrapper = g_object_new (CAMEL_TYPE_IMAP_WRAPPER, NULL);
 	camel_data_wrapper_set_mime_type_field (CAMEL_DATA_WRAPPER (imap_wrapper), type);
