@@ -54,6 +54,7 @@ static CamelProvider mh_provider = {
 	CAMEL_PROVIDER_IS_SOURCE | CAMEL_PROVIDER_IS_STORAGE | CAMEL_PROVIDER_IS_LOCAL,
 	CAMEL_URL_NEED_PATH | CAMEL_URL_NEED_PATH_DIR | CAMEL_URL_PATH_IS_ABSOLUTE | CAMEL_URL_FRAGMENT_IS_PATH,
 	mh_conf_entries,
+	NULL,
 	/* ... */
 };
 
@@ -72,6 +73,7 @@ static CamelProvider mbox_provider = {
 	CAMEL_PROVIDER_IS_SOURCE | CAMEL_PROVIDER_IS_STORAGE | CAMEL_PROVIDER_IS_LOCAL,
 	CAMEL_URL_NEED_PATH | CAMEL_URL_PATH_IS_ABSOLUTE | CAMEL_URL_FRAGMENT_IS_PATH,
 	mbox_conf_entries,
+	NULL,
 	/* ... */
 };
 
@@ -94,6 +96,7 @@ static CamelProvider maildir_provider = {
 	CAMEL_PROVIDER_IS_SOURCE | CAMEL_PROVIDER_IS_STORAGE | CAMEL_PROVIDER_IS_LOCAL,
 	CAMEL_URL_NEED_PATH | CAMEL_URL_NEED_PATH_DIR | CAMEL_URL_PATH_IS_ABSOLUTE | CAMEL_URL_FRAGMENT_IS_PATH,
 	maildir_conf_entries,
+	NULL,
 	/* ... */
 };
 
@@ -114,6 +117,7 @@ static CamelProvider spool_file_provider = {
 	CAMEL_PROVIDER_IS_SOURCE | CAMEL_PROVIDER_IS_STORAGE,
 	CAMEL_URL_NEED_PATH | CAMEL_URL_PATH_IS_ABSOLUTE | CAMEL_URL_FRAGMENT_IS_PATH,
 	spool_conf_entries,
+	NULL,
 	/* ... */
 };
 
@@ -125,6 +129,7 @@ static CamelProvider spool_directory_provider = {
 	CAMEL_PROVIDER_IS_SOURCE | CAMEL_PROVIDER_IS_STORAGE,
 	CAMEL_URL_NEED_PATH | CAMEL_URL_NEED_PATH_DIR | CAMEL_URL_PATH_IS_ABSOLUTE | CAMEL_URL_FRAGMENT_IS_PATH,
 	spool_conf_entries,
+	NULL,
 	/* ... */
 };
 
@@ -164,7 +169,7 @@ local_url_hash (gconstpointer v)
 	const CamelURL *u = v;
 	guint hash = 0;
 
-#define ADD_HASH(s) if (s) hash ^= g_str_hash (s);
+#define ADD_HASH(s) if (s && *s) hash ^= g_str_hash (s);
 
 	ADD_HASH (u->protocol);
 	ADD_HASH (u->user);
