@@ -40,22 +40,88 @@
 
 #define d(x) /*(printf("%s(%d): ", __FILE__, __LINE__),(x))*/
 
-static CamelLocalSummary *spool_create_summary(CamelLocalFolder *lf, const gchar *path, const gchar *folder, CamelIndex *index);
-
-static gint spool_lock(CamelLocalFolder *lf, CamelLockType type, CamelException *ex);
-static void spool_unlock(CamelLocalFolder *lf);
-
 G_DEFINE_TYPE (CamelSpoolFolder, camel_spool_folder, CAMEL_TYPE_MBOX_FOLDER)
 
+static CamelLocalSummary *
+spool_folder_create_summary (CamelLocalFolder *lf,
+                             const gchar *path,
+                             const gchar *folder,
+                             CamelIndex *index)
+{
+	return (CamelLocalSummary *) camel_spool_summary_new (
+		CAMEL_FOLDER (lf), folder);
+}
+
+static gint
+spool_folder_lock (CamelLocalFolder *lf,
+                   CamelLockType type,
+                   GError **error)
+{
+	gint retry = 0;
+	CamelMboxFolder *mf = (CamelMboxFolder *)lf;
+	CamelSpoolFolder *sf = (CamelSpoolFolder *)lf;
+	GError *local_error = NULL;
+
+	mf->lockfd = open (lf->folder_path, O_RDWR|O_LARGEFILE, 0);
+	if (mf->lockfd == -1) {
+		g_set_error (
+			error, G_IO_ERROR,
+			g_io_error_from_errno (errno),
+			_("Cannot create folder lock on %s: %s"),
+			lf->folder_path, g_strerror (errno));
+		return -1;
+	}
+
+	while (retry < CAMEL_LOCK_RETRY) {
+		if (retry > 0)
+			sleep (CAMEL_LOCK_DELAY);
+
+		g_clear_error (&local_error);
+
+		if (camel_lock_fcntl (mf->lockfd, type, &local_error) == 0) {
+			if (camel_lock_flock (mf->lockfd, type, &local_error) == 0) {
+				if ((sf->lockid = camel_lock_helper_lock (lf->folder_path, &local_error)) != -1)
+					return 0;
+				camel_unlock_flock (mf->lockfd);
+			}
+			camel_unlock_fcntl (mf->lockfd);
+		}
+		retry++;
+	}
+
+	close (mf->lockfd);
+	mf->lockfd = -1;
+
+	if (local_error != NULL)
+		g_propagate_error (error, local_error);
+
+	return -1;
+}
+
+static void
+spool_folder_unlock (CamelLocalFolder *lf)
+{
+	CamelMboxFolder *mf = (CamelMboxFolder *)lf;
+	CamelSpoolFolder *sf = (CamelSpoolFolder *)lf;
+
+	camel_lock_helper_unlock (sf->lockid);
+	sf->lockid = -1;
+	camel_unlock_flock (mf->lockfd);
+	camel_unlock_fcntl (mf->lockfd);
+
+	close (mf->lockfd);
+	mf->lockfd = -1;
+}
+
 static void
 camel_spool_folder_class_init (CamelSpoolFolderClass *class)
 {
 	CamelLocalFolderClass *local_folder_class;
 
 	local_folder_class = CAMEL_LOCAL_FOLDER_CLASS (class);
-	local_folder_class->create_summary = spool_create_summary;
-	local_folder_class->lock = spool_lock;
-	local_folder_class->unlock = spool_unlock;
+	local_folder_class->create_summary = spool_folder_create_summary;
+	local_folder_class->lock = spool_folder_lock;
+	local_folder_class->unlock = spool_folder_unlock;
 }
 
 static void
@@ -68,16 +134,20 @@ CamelFolder *
 camel_spool_folder_new (CamelStore *parent_store,
                         const gchar *full_name,
                         guint32 flags,
-                        CamelException *ex)
+                        GCancellable *cancellable,
+                        GError **error)
 {
 	CamelFolder *folder;
+	CamelURL *url;
 	gchar *basename;
 
+	url = camel_service_get_camel_url (CAMEL_SERVICE (parent_store));
+
 	basename = g_path_get_basename (full_name);
 
 	folder = g_object_new (
 		CAMEL_TYPE_SPOOL_FOLDER,
-		"name", basename, "full-name", full_name,
+		"display-name", basename, "full-name", full_name,
 		"parent-store", parent_store, NULL);
 
 	if (parent_store->flags & CAMEL_STORE_FILTER_INBOX
@@ -86,10 +156,10 @@ camel_spool_folder_new (CamelStore *parent_store,
 	flags &= ~CAMEL_STORE_FOLDER_BODY_INDEX;
 
 	folder = (CamelFolder *)camel_local_folder_construct (
-		(CamelLocalFolder *)folder, flags, ex);
+		(CamelLocalFolder *)folder, flags, cancellable, error);
 	if (folder) {
-		if (camel_url_get_param(((CamelService *)parent_store)->url, "xstatus"))
-			camel_mbox_summary_xstatus((CamelMboxSummary *)folder->summary, TRUE);
+		if (camel_url_get_param (url, "xstatus"))
+			camel_mbox_summary_xstatus ((CamelMboxSummary *)folder->summary, TRUE);
 	}
 
 	g_free (basename);
@@ -97,68 +167,3 @@ camel_spool_folder_new (CamelStore *parent_store,
 	return folder;
 }
 
-static CamelLocalSummary *
-spool_create_summary (CamelLocalFolder *lf,
-                      const gchar *path,
-                      const gchar *folder,
-                      CamelIndex *index)
-{
-	return (CamelLocalSummary *) camel_spool_summary_new (
-		CAMEL_FOLDER (lf), folder);
-}
-
-static gint
-spool_lock (CamelLocalFolder *lf,
-            CamelLockType type,
-            CamelException *ex)
-{
-	gint retry = 0;
-	CamelMboxFolder *mf = (CamelMboxFolder *)lf;
-	CamelSpoolFolder *sf = (CamelSpoolFolder *)lf;
-
-	mf->lockfd = open(lf->folder_path, O_RDWR|O_LARGEFILE, 0);
-	if (mf->lockfd == -1) {
-		camel_exception_setv (
-			ex, CAMEL_EXCEPTION_SYSTEM,
-			_("Cannot create folder lock on %s: %s"),
-			lf->folder_path, g_strerror (errno));
-		return -1;
-	}
-
-	while (retry < CAMEL_LOCK_RETRY) {
-		if (retry > 0)
-			sleep(CAMEL_LOCK_DELAY);
-
-		camel_exception_clear(ex);
-
-		if (camel_lock_fcntl(mf->lockfd, type, ex) == 0) {
-			if (camel_lock_flock(mf->lockfd, type, ex) == 0) {
-				if ((sf->lockid = camel_lock_helper_lock(lf->folder_path, ex)) != -1)
-					return 0;
-				camel_unlock_flock(mf->lockfd);
-			}
-			camel_unlock_fcntl(mf->lockfd);
-		}
-		retry++;
-	}
-
-	close (mf->lockfd);
-	mf->lockfd = -1;
-
-	return -1;
-}
-
-static void
-spool_unlock (CamelLocalFolder *lf)
-{
-	CamelMboxFolder *mf = (CamelMboxFolder *)lf;
-	CamelSpoolFolder *sf = (CamelSpoolFolder *)lf;
-
-	camel_lock_helper_unlock(sf->lockid);
-	sf->lockid = -1;
-	camel_unlock_flock(mf->lockfd);
-	camel_unlock_fcntl(mf->lockfd);
-
-	close(mf->lockfd);
-	mf->lockfd = -1;
-}
