@@ -321,6 +321,8 @@ pop3_folder_get_message_sync (CamelFolder *folder,
 	gint i, last;
 	CamelStream *stream = NULL;
 
+	g_return_val_if_fail (uid != NULL, NULL);
+
 	parent_store = camel_folder_get_parent_store (folder);
 
 	pop3_folder = CAMEL_POP3_FOLDER (folder);
@@ -654,7 +656,7 @@ camel_pop3_folder_new (CamelStore *parent,
 
 	folder = g_object_new (
 		CAMEL_TYPE_POP3_FOLDER,
-		"full-name", "inbox", "name", "inbox",
+		"full-name", "inbox", "display-name", "inbox",
 		"parent-store", parent, NULL);
 
 	/* mt-ok, since we dont have the folder-lock for new() */
@@ -723,7 +725,7 @@ camel_pop3_delete_old (CamelFolder *folder,
 	gint i;
 	CamelPOP3Store *pop3_store;
 	CamelMimeMessage *message;
-	time_t temp, message_time = 0;
+	time_t temp, message_time;
 
 	parent_store = camel_folder_get_parent_store (folder);
 
@@ -733,8 +735,22 @@ camel_pop3_delete_old (CamelFolder *folder,
 
 	d(printf("%s(%d): pop3_folder->uids->len=[%d]\n", __FILE__, __LINE__, pop3_folder->uids->len));
 	for (i = 0; i < pop3_folder->uids->len; i++) {
+		message_time = 0;
 		fi = pop3_folder->uids->pdata[i];
 
+		if (fi->cmd) {
+			while (camel_pop3_engine_iterate (pop3_store->engine, fi->cmd) > 0) {
+				; /* do nothing - iterating until end */
+			}
+
+			camel_pop3_engine_command_free (pop3_store->engine, fi->cmd);
+			fi->cmd = NULL;
+		}
+
+		/* continue, if message wasn't received yet */
+		if (!fi->uid)
+			continue;
+
 		d(printf("%s(%d): fi->uid=[%s]\n", __FILE__, __LINE__, fi->uid));
 		if (!pop3_get_message_time_from_cache (folder, fi->uid, &message_time)) {
 			d(printf("could not get message time from cache, trying from pop3\n"));
