@@ -25,17 +25,26 @@
 #include <config.h>
 #endif
 
+#include <camel/camel.h>
 #include <glib/gi18n-lib.h>
 
-#include "camel-provider.h"
-#include "camel-sasl.h"
-#include "camel-session.h"
 #include "camel-smtp-transport.h"
-#include "camel-url.h"
+
+#ifdef G_OS_WIN32
+#include <winsock2.h>
+#include <ws2tcpip.h>
+#endif
 
 static guint smtp_url_hash (gconstpointer key);
 static gint smtp_url_equal (gconstpointer a, gconstpointer b);
 
+CamelProviderPortEntry smtp_port_entries[] = {
+						  { 25, N_("Default SMTP port"), FALSE },
+						  { 465, N_("SMTP over SSL"), TRUE },
+						  { 587, N_("Message submission port"), FALSE },
+						  { 0, NULL, 0 }
+					     };
+
 static CamelProvider smtp_provider = {
 	"smtp",
 	N_("SMTP"),
@@ -49,11 +58,15 @@ static CamelProvider smtp_provider = {
 
 	CAMEL_URL_NEED_HOST | CAMEL_URL_ALLOW_AUTH | CAMEL_URL_ALLOW_USER,
 
+	NULL,
+
+	smtp_port_entries,
+
 	/* ... */
 };
 
 void
-camel_provider_module_init(void)
+camel_provider_module_init (void)
 {
 	smtp_provider.object_types[CAMEL_PROVIDER_TRANSPORT] = camel_smtp_transport_get_type ();
 	smtp_provider.authtypes = g_list_append (camel_sasl_authtype_list (TRUE), camel_sasl_authtype ("LOGIN"));
@@ -62,7 +75,7 @@ camel_provider_module_init(void)
 	smtp_provider.url_equal = smtp_url_equal;
 	smtp_provider.translation_domain = GETTEXT_PACKAGE;
 
-	camel_provider_register(&smtp_provider);
+	camel_provider_register (&smtp_provider);
 }
 
 static void
